var express = require("express");
const Order = require("../../app/Order");
const Manual = require("../../app/payment_processor/Manual");
const config = require("config");
var router = express.Router({ mergeParams: true });
const { query, validationResult, matchedData } = require("express-validator");
const dayjs = require("dayjs");
const crypto = require("crypto");
const RedisClient = require("../../app/RedisClient");
const Cash = require("../../app/payment_processor/Cash");
const PaymentReference = require("../../app/PaymentReference");

router.use("/", (req, res, next) => {
  if (req.data && req.data.checkout) {
    req.data.checkout.payment = {
      provider: "cash",
    };
    req.data.checkout.payment_reference = {};
  }
  req.data.css.push(`${res.locals.baseDir}/styles/key/checkout-cash.css`);
  next();
});

router.get(
  "/",
  async (req, res) => {
    PaymentReference.CREATE_NEW_REQUEST(
      req.data.checkout.amount,
      req.data.key.key.get_key(),
      dayjs().add(2, "month")
    ).then(async payment_reference => {
      req.data.checkout.payment_reference = payment_reference;
      res.render("key", req.data);
    }).catch(reason => {
      console.error(reason);
      res.render("key", req.data);
    });
  }
);

router.post("/", (req, res) => {
  /**
   * @type {Order}
   */
  let new_order = null;
  Order.CREATE_NEW_ORDER(
    req.params.amount,
    req.data.key.key.get_key(),
    new Manual(req.body.note),
    req.t
  )
    .then((order) => {
      new_order = order;
      return order.captureOrder();
    })
    .then(() => new_order.chargeKey())
    .then(() => {
      let redirect_url =
        `${res.locals.baseDir}/key/` +
        req.data.key.key.get_key() +
        "/orders/" +
        new_order.getOrderID();
      res.redirect(redirect_url);
    });
});

router.use((next) => {
  next();
});

module.exports = router;
