var express = require("express");
var router = express.Router();

const config = require("config");
const Order = require("../../app/Order.js");

router.post(
  "/",
  (req, res, next) => {
    if (process.env.NODE_ENV !== "development") {
      res.status(400).json({
        errors: [
          { msg: "Payment method only allowed in development environment." },
        ],
      });
    } else {
      next();
    }
  },
  (req, res) => {
    // Order data is validated: Create and store the order in the redis database
    let order = new Order(
      req.body.order_id,
      req.body.expires_at,
      req.body.amount,
      req.body.unit_size,
      req.body.price_per_unit,
      req.body.encrypted_sales_receipts
    );

    order
      .save()
      .then(() => {
        order.signOrder().then(() => {
          order.save().then(() => {
            res.json({
              order_id: req.body.order_id,
              expires_at: req.body.expires_at,
              signatures: order.getSignatures(),
            });
          });
        });
      })
      .catch((reason) => {
        return res.status(400).json({
          errors: [
            {
              msg: reason,
            },
          ],
        });
      });
  }
);

module.exports = router;
